/****************************************************************************
 *
 * Copy right:   Qx.Chen Jie
 * File name:    AppTaskControl.c
 * Description:  LED控制和蜂鸣器控制和继电器控制逻辑判定
 * History:      2021-07-05
 * Version:      V3.0
 ****************************************************************************/
#include "AppTaskControl.h"

static StaticTask_t gProcess_Control_Task_t;
static UINT8 gProcess_Control_TaskStack[PROC_CONTROL_TASK_STACK_SIZE];
static osThreadId_t ControlTaskId = NULL;
static process_control gProcess_Control_Task = PROCESS_CONTROL_STATE_IDLE;
#define PROC_CONTROL_STATE_SWITCH(a) (gProcess_Control_Task = a)
void GetAdcValue(UINT8 num);
static void ControlTask(void *arg)
{
    /*AD采样初始化*/
    UINT32 param;
    PROC_CONTROL_STATE_SWITCH(PROCESS_CONTROL_STATE_IDLE);
    UINT32 CurrentTime = 0;
    UINT16 RingTimes = 0;
    UINT8 AdcIndex = 1;
    while (true)
    {
        switch (gProcess_Control_Task)
        {
        case PROCESS_CONTROL_STATE_IDLE:
        {
            AdcSendReq(ADC_REQ_BITMAP_VBAT_CALI, &param, 1, ADC_GET_RESULT_TIMOUT);
            AdcSendReq(ADC_REQ_BITMAP_INRES_CALI, &param, 1, ADC_GET_RESULT_TIMOUT);
            NetSocDisplay(LED_SOC_0, LED_TURN_OFF);
            NetSocDisplay(LED_SOC_1, LED_TURN_OFF);
            NetSocDisplay(LED_SOC_2, LED_TURN_OFF);
            NetSocDisplay(LED_SOC_3, LED_TURN_OFF);
            FaultDisplay(LED_TURN_OFF);
            osDelay(100);
            PROC_CONTROL_STATE_SWITCH(PROCESS_CONTROL_STATE_WORK);
            break;
        }
        case PROCESS_CONTROL_STATE_WORK:
        {
            osDelay(10);
            if (CurrentTime != TimeCounter)
            {
                UINT16 Buzzerperiod = 400;
                LEDDisplay();
                if (AppDataInfo.BattLock == FALSE && getbit(UartCmdRecvFlag, 0) == 1)
                {
                    relayControlFunc(Buzzerperiod, 0.5);
                    RingTimes = RingTimes + 100;
                    if (RingTimes >= 3 * Buzzerperiod)
                    {
                        RingTimes = 0;
                        clrbit(UartCmdRecvFlag, 0);
                    }
                }
                else if (AppDataInfo.BattLock == TRUE && getbit(UartCmdRecvFlag, 0) == 1)
                {
                    relayControlFunc(Buzzerperiod, 0.5);
                    RingTimes = RingTimes + 100;
                    if (RingTimes >= 2 * Buzzerperiod)
                    {
                        RingTimes = 0;
                        clrbit(UartCmdRecvFlag, 0);
                    }
                }
                else if (BuzzerControl == TRUE || getbit(sfmd_st_fltAct, 2) == 1 || UDSSwitch == 1)
                {
                    relayControlFunc(Buzzerperiod, 0.5);
                }
                else if (TimeCounter % 10 == 0)
                {
                    relayControl(FALSE);
                }
                CurrentTime = TimeCounter;
                GetAdcValue(AdcIndex);
                AdcIndex++;
                if (AdcIndex > 5)
                {
                    AdcIndex = 0;
                }

                if (gProcess_app != WORK)
                {
                    NetSocDisplay(LED_SOC_0, LED_TURN_OFF);
                    NetSocDisplay(LED_SOC_1, LED_TURN_OFF);
                    NetSocDisplay(LED_SOC_2, LED_TURN_OFF);
                    NetSocDisplay(LED_SOC_3, LED_TURN_OFF);
                    FaultDisplay(LED_TURN_OFF);
                    PROC_CONTROL_STATE_SWITCH(PROCESS_CONTROL_STATE_SLEEP);
                    break;
                }
                //临时故障诊断函数--改为模型诊断
                ErrorNumHandleFunc();
            }
            break;
        }
        case PROCESS_CONTROL_STATE_SLEEP:
        {
            osDelay(100);
            if (TimeCounter % (10 * 600) == 0)
            {
                AdcIndex = 0;
                while (AdcIndex < 5)
                {
                    GetAdcValue(AdcIndex + 1);
                    AdcIndex++;
                    osDelay(200);
                }
                otherTempAvg = (heatTemp1 + heatTemp2 + fastChargeTemp + normalChargeTemp) / 4;
            }
            if (gProcess_app == WORK)
            {
                PROC_CONTROL_STATE_SWITCH(PROCESS_CONTROL_STATE_WORK);
            }
            break;
        }
        }
    }
}
void AppTaskControlInit(void *arg)
{
    osThreadAttr_t task_attr;
    memset(&task_attr, 0, sizeof(task_attr));
    memset(gProcess_Control_TaskStack, 0xA5, PROC_CONTROL_TASK_STACK_SIZE);
    task_attr.name = "Control_Task";
    task_attr.stack_mem = gProcess_Control_TaskStack;
    task_attr.stack_size = PROC_CONTROL_TASK_STACK_SIZE;
    task_attr.priority = osPriorityBelowNormal7;
    task_attr.cb_mem = &gProcess_Control_Task_t;
    task_attr.cb_size = sizeof(StaticTask_t);
    ControlTaskId = osThreadNew(ControlTask, NULL, &task_attr);
}
void AppTaskControlDeInit(void *arg)
{
    osThreadTerminate(ControlTaskId);
    ControlTaskId = NULL;
}
void GetAdcValue(UINT8 num)
{
    UINT32 adcValue = 0;
    switch (num)
    {
    case FAST_CHARGE_TEMP:
        NB_ADC_Get(&adcValue, FAST_CHARGE_TEMP);
        fastChargeTemp = LookUpRTtable(adcValue);
        break;
    case NORMAL_CHARGE_TEMP:
        NB_ADC_Get(&adcValue, NORMAL_CHARGE_TEMP);
        normalChargeTemp = LookUpRTtable(adcValue);
        break;
    case OTHER_TEMP_1:
        NB_ADC_Get(&adcValue, OTHER_TEMP_1);
        heatTemp1 = LookUpRTtable(adcValue);
        break;
    case OTHER_TEMP_2:
        NB_ADC_Get(&adcValue, OTHER_TEMP_2);
        heatTemp2 = LookUpRTtable(adcValue);
        break;
    case VBAT:
        NB_ADC_Get(&adcValue, VBAT);
        PowerVoltage = adcValue;
    default:
        break;
    }
}